pub struct DownloadStates {
pub audio: Option<bool>,
pub camera: Option<bool>,
pub screen: Option<bool>,
pub camera_layout: Option<VideoLayoutIntent>,
pub screen_layout: Option<VideoLayoutIntent>,
}Expand description
receiver intent for which streams to download from one peer
this is client intent, not a transport subscription object missing fields mean the current receiver preference for that stream or layout should be left unchanged
Fields
audio: Option<bool>camera: Option<bool>screen: Option<bool>camera_layout: Option<VideoLayoutIntent>screen_layout: Option<VideoLayoutIntent>Implementations
Sourceimpl DownloadStates
impl DownloadStates
pub fn apply_partial_update(&mut self, update: &Self)